==> mx-compton_18.11.tar.xz: mx-compton/translations/mx-compton_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>mxcompton</name>
    <message>
        <location filename="../mxcompton.ui" line="14"/>
        <source>MX Compton Manager</source>
        <translation>MX Comptonin hallinta</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="88"/>
        <source>Quit application</source>
        <translation>Sulje sovellus</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="91"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="98"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="108"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="119"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="134"/>
        <source>Xfce compositor will be disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="137"/>
        <location filename="../mxcompton.cpp" line="110"/>
        <location filename="../mxcompton.cpp" line="146"/>
        <source>Launch Compton</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="149"/>
        <source>Launch compton-conf configuration tool</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="152"/>
        <source>Compton settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="164"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="167"/>
        <source>Edit compton.conf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="195"/>
        <source>Launch Compton at login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="107"/>
        <source>Stop Compton</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="167"/>
        <source>About MX Compton</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="168"/>
        <location filename="../mxcompton.cpp" line="175"/>
        <location filename="../mxcompton.cpp" line="185"/>
        <source>MX Compton</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="168"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="169"/>
        <source>Configure Compton Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="171"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="172"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="173"/>
        <location filename="../mxcompton.cpp" line="175"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
</context>
</TS>

==> mx-compton_19.01.tar.xz: mx-compton/translations/mx-compton_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>mxcompton</name>
    <message>
        <location filename="../mxcompton.ui" line="14"/>
        <source>MX Compton Manager</source>
        <translation>MX Comptonin hallinta</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="88"/>
        <source>Quit application</source>
        <translation>Sulje sovellus</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="91"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="98"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="108"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="119"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="134"/>
        <source>Xfce compositor will be disabled</source>
        <translation>Xfce-kompositoija poistetaan käytöstä</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="137"/>
        <location filename="../mxcompton.cpp" line="110"/>
        <location filename="../mxcompton.cpp" line="146"/>
        <source>Launch Compton</source>
        <translation>Käynnistä Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="149"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Käynnistä compton-conf konfigurointityökalut</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="152"/>
        <source>Compton settings</source>
        <translation>Comptonin asetukset</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="164"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Muokkaa compton.conf -tiedostoa suoraan tekstieditorissa</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="167"/>
        <source>Edit compton.conf</source>
        <translation>Muokkaa compton.conf</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="195"/>
        <source>Launch Compton at login</source>
        <translation>Käynnistä Compton kirjautuessa</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="107"/>
        <source>Stop Compton</source>
        <translation>Pysäytä Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="167"/>
        <source>About MX Compton</source>
        <translation>Tietoja MX Comptonista</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="168"/>
        <location filename="../mxcompton.cpp" line="175"/>
        <location filename="../mxcompton.cpp" line="185"/>
        <source>MX Compton</source>
        <translation>MX Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="168"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="169"/>
        <source>Configure Compton Settings</source>
        <translation>Konfiguroi Comptonin asetukset</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="171"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="172"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="173"/>
        <location filename="../mxcompton.cpp" line="175"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
</context>
</TS>
